package Perl::Critic::Policy::ProhibitSmartmatch;

our $VERSION = '0.2';

=encoding utf-8

=head1 NAME

Perl::Critic::Policy::ProhibitSmartmatch
- avoid using both explicit and implicit smartmatching

=head1 DESCRIPTION

This distribution provides two Perl::Critic policies
which help to avoid both explicit and implicit smartmatching.

=head1 AUTHOR

Jan Holcapek E<lt>holcapek@gmail.comE<gt>, who was heavily inspired by the work of
hisaichi5518 E<lt>hisada.kazuki@gmail.comE<gt>

=cut

